Maker API
=========

:obj:`Maker` objects are powerful generator classes for containing and customising
keyword arguments, particularly for dynamic job creation.

.. currentmodule:: jobflow.core.maker

.. autoclass:: Maker
   :noindex:
   :members:
   :show-inheritance:
